@@ -8,7 +8,7 @@ def grouper(n, iterable, fillvalue=None):
   return izip_longest(fillvalue=fillvalue, *args)
 
 class Leaderboard(object):
-  VERSION = '2.5.0'
+  VERSION = '2.6.0'
   DEFAULT_PAGE_SIZE = 25
   DEFAULT_REDIS_HOST = 'localhost'
   DEFAULT_REDIS_PORT = 6379
@@ -495,6 +495,43 @@ class Leaderboard(object):
     else:
       return percentile
 
+  def score_for_percentile(self, percentile):
+    '''
+    Calculate the score for a given percentile value in the leaderboard.
+    @param percentile [float] Percentile value (0.0 to 100.0 inclusive).
+    @return the score corresponding to the percentile argument. Return +None+ for arguments outside 0-100 inclusive and for leaderboards with no members.
+    '''
+    return self.score_for_percentile_in(self.leaderboard_name, percentile)
+
+  def score_for_percentile_in(self, leaderboard_name, percentile):
+    '''
+    Calculate the score for a given percentile value in the leaderboard.
+    @param leaderboard_name [String] Name of the leaderboard.
+    @param percentile [float] Percentile value (0.0 to 100.0 inclusive).
+    @return the score corresponding to the percentile argument. Return +None+ for arguments outside 0-100 inclusive and for leaderboards with no members.
+    '''
+    if not 0 <= percentile <= 100:
+      return None
+
+    total_members = self.total_members_in(leaderboard_name)
+    if total_members < 1:
+      return None
+
+    if self.order == self.ASC:
+      percentile = 100 - percentile
+
+    index = (total_members - 1) * (percentile / 100.0)
+
+    scores = [pair[1] for pair in self.redis_connection.zrange(
+      leaderboard_name, int(math.floor(index)), int(math.ceil(index)), withscores = True
+    )]
+
+    if index == math.floor(index):
+      return scores[0]
+    else:
+      interpolate_fraction = index - math.floor(index)
+      return scores[0] + interpolate_fraction * (scores[1] - scores[0])
+
   def expire_leaderboard(self, seconds):
     '''
     Expire the current leaderboard in a set number of seconds. Do not use this with
